pub trait CompartmentMeshManip {
// Required methods
fn are_cell_neighbor(
&self,
cell1_id: usize,
cell2_id: usize,
) -> NeighborDirection;
fn cell_surface(&self, cell_id: usize, i_axis: OrientedAxis) -> f64;
fn cell_volume(&self, cell_id: usize) -> f64;
fn cell_from_coordinates(&self, coords: &Coords3) -> Option<usize>;
fn is_point_inside(&self, cell_id: usize, point_coords: &Coords3) -> bool;
fn cell_points(&self, cell_1d: usize) -> AxisPoints;
fn n_maximum_interface(&self) -> usize;
fn get_interface_plane(
&self,
cell1_id: usize,
cell2_id: usize,
) -> (BoundedPlane, usize);
fn cell_from_ax_points(&self, axis_points: &AxisPoints) -> Option<usize>;
fn get_boundary(&self) -> Vec<usize>;
}Expand description
Trait for manipulating and querying properties of cells in a compartment mesh.
Required Methods
Sourcefn are_cell_neighbor(
&self,
cell1_id: usize,
cell2_id: usize,
) -> NeighborDirection
fn are_cell_neighbor( &self, cell1_id: usize, cell2_id: usize, ) -> NeighborDirection
Sourcefn cell_surface(&self, cell_id: usize, i_axis: OrientedAxis) -> f64
fn cell_surface(&self, cell_id: usize, i_axis: OrientedAxis) -> f64
Sourcefn cell_volume(&self, cell_id: usize) -> f64
fn cell_volume(&self, cell_id: usize) -> f64
Sourcefn cell_from_coordinates(&self, coords: &Coords3) -> Option<usize>
fn cell_from_coordinates(&self, coords: &Coords3) -> Option<usize>
Sourcefn is_point_inside(&self, cell_id: usize, point_coords: &Coords3) -> bool
fn is_point_inside(&self, cell_id: usize, point_coords: &Coords3) -> bool
Sourcefn cell_points(&self, cell_1d: usize) -> AxisPoints
fn cell_points(&self, cell_1d: usize) -> AxisPoints
Sourcefn n_maximum_interface(&self) -> usize
fn n_maximum_interface(&self) -> usize
Returns the maximum number of interfaces a cell can have in this mesh.
Returns
The maximum number of interfaces as a usize.